.. _notebooks:

#####################################
IPython notebooks for Nibabel project
#####################################

*****************************
Rotation matrix orthogonality
*****************************

See :download:`ATA error calculations <ata_error.ipynb>` and :download:`Cross
product error <cross_product_error.ipynb>`.  You can use the `IPython notebook
viewer`_ to view these files; copy the URL and paste into the Notebook viewer
URL box.

.. include:: ../links_names.txt
